import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/my_appbar.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:widgets/widget_export.dart';

import '../../../router/page/community_page_router.dart';
import '../community_vm.dart';
import 'foryou_vm.dart';

@RoutePage()
class ForyouPage extends HookConsumerWidget {
  const ForyouPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context}) {
    if (context != null) {
      context.router.push(const ForyouPageRoute());
    } else {
      appRouter.push(const ForyouPageRoute());
    }
  }

  bool _isPreventScroll(ScrollNotification notification, WidgetRef ref){
    // 检查当前页面是否是可见的
    bool isDownOrUp = notification.metrics.axis == Axis.vertical;
    if (notification is UserScrollNotification) {
      // 检查滚动方向
      switch (notification.direction) {
        case ScrollDirection.forward:
          print('Scrolling down');
          break;
        case ScrollDirection.reverse:
          print('Scrolling up');
          break;
        case ScrollDirection.idle:
          print('Scrolling stopped');
          break;
      }
    } else if (notification is ScrollUpdateNotification) {
      // 检查滚动位置变化
      double currentScrollPosition = notification.metrics.pixels;
      double maxScrollExtent = notification.metrics.maxScrollExtent;

      // 判断是否满足某个条件
      if (currentScrollPosition > 0 && currentScrollPosition < maxScrollExtent) {
        print('Current scroll position: $currentScrollPosition');
        // 在这里添加你的条件判断逻辑
      }

      // 只有当上下滚动时才拦截通知
      if (isDownOrUp) {
        final vm = ref.read(communityVmProvider.notifier);
        final currentTabRouter = vm.state!.tabsRouter;
        if(currentTabRouter!.activeIndex == 2){
          return false;  // false 不拦截
        }else {
          Log.d("----news_page 滚动时---拦截了其他的");
          return true;   // true 拦截
        }
      }
    }
    return false;
  }


  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final vm = ref.read(foryouVmProvider.notifier);
    return Scaffold(
      // appBar: MyAppBar.appBar(
      //   context,
      //   "foryou",
      //   backgroundColor: context.appColors.whiteBG,
      // ),
      // backgroundColor: ColorUtils.string2Color("#F2F3F6"),
        body: Column(
          mainAxisSize: MainAxisSize.max,
          children: [
            Expanded(
              child: NotificationListener<ScrollNotification>(
                onNotification: (ScrollNotification notification) {
                  // 是否拦截滚动  false 表示不拦截通知
                  return _isPreventScroll(notification, ref);
                  // return false;
                },
                child: EasyRefresh(
                  key: UniqueKey(),
                  controller: EasyRefreshController(),
                  // 上拉加载
                  onLoad: () async{
                    Log.d("----onLoad");
                    vm.onLoadData();
                  },
                  // 下拉刷新
                  onRefresh: () async{
                    Log.d("----onRefresh");
                    vm.refreshListData();
                  },
                  child: _buildForyouList(context, ref, vm),
                ),
              ),
            )
          ],
        )
    );
  }


  Widget _buildForyouList(BuildContext context, WidgetRef ref, ForyouVm vm) {

    return ListView.builder(
      itemCount: 3,
      itemBuilder: (context, index) {
        return _buildListItem(context, ref, vm, index);
      },
    );
  }

  Widget _buildListItem(BuildContext context, WidgetRef ref, ForyouVm vm, int index) {
    return Text("list-item");
  }

}