import 'package:cpt_community/modules/my_posts/my_posts_newsfeed/my_posts_newsfeed_vm.dart';
import 'package:cpt_community/router/page/community_page_router.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/widget_export.dart';

import '../../../components/newsfeed_card_content.dart';
import '../../../components/newsfeed_card_footer.dart';
import '../my_posts_tabs.dart';
import 'newsfeed_itemgroup_state.dart';
import 'newsfeed_sticky_header.dart';

@RoutePage()
class MyPostsNewsfeedPage extends HookConsumerWidget {
  const MyPostsNewsfeedPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context}) {
    if (context != null) {
      context.router.push(const MyPostsNewsfeedPageRoute());
    } else {
      appRouter.push(const MyPostsNewsfeedPageRoute());
    }
  }

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final vm = ref.read(myPostsNewsfeedVmProvider.notifier);
    useEffect((){
      // 组件挂载时执行 - 执行接口请求
      Future.microtask(() => vm.initPageData());
      return null;
    },[]);

    return Scaffold(
      // appBar: MyAppBar.appBar(
      //   context,
      //   "My Posts",
      //   backgroundColor: context.appColors.whiteBG,
      // ),
      // backgroundColor: context.appColors.backgroundDefault,
      backgroundColor: ColorUtils.string2Color('#F2F3F6'),
      body: SizedBox(
        width: double.infinity,
        height: double.infinity,
        child: Column(
          children: [
            // _buildHeaderTabs(context, ref),
            _buildContentBody(context, ref),
          ],
        ),
      ),
    );
  }

  Widget _buildHeaderTabs(BuildContext context, WidgetRef ref) {
    final state = ref.watch(myPostsNewsfeedVmProvider);
    final vm = ref.read(myPostsNewsfeedVmProvider.notifier);
    return Container(
        color: Colors.blue,
        child: MyPostsTab(
          key: UniqueKey(),
          tabsList: state.tabsList!,
          tabsRouter: null,
          onClickAction:(activeTabIdx){
            Log.d("点击的tab index: $activeTabIdx");
            vm.handlerChangeTab(context, activeTabIdx);
          },
        ),
    );
  }

  Widget _buildContentBody(BuildContext context, WidgetRef ref) {
    final vm = ref.read(myPostsNewsfeedVmProvider.notifier);
    final state = ref.watch(myPostsNewsfeedVmProvider);
    return Expanded(
      child: Container(
        // color: Colors.red,
        child: EasyRefresh(
          controller: vm.refreshController,
          // 上拉加载
          onLoad: () async{
            Log.d("----onLoad");
            vm.loadMore();
          },
          // 下拉刷新
          onRefresh: () async{
            Log.d("----onRefresh");
            vm.onRefresh();
          },
          child: LoadStateLayout(
            state: state.loadingState,
            errorMessage: state.errorMessage,
            errorRetry: () {
              vm.retryRequest();
            },
            successSliverWidget:[
              SliverList(
                  delegate: SliverChildBuilderDelegate(
                        (context, index) {
                      return StickyHeader(
                        header: _buildHeaderContent(state.list![index]),
                        content: Column(
                          children: _buildGroupContent(state.list![index].itemgroupDatas , index, vm),
                        ),
                      );
                    },
                    childCount: state.list!.length,
                  ))
            ]
          )
        ),
      ),
    );
  }

  Widget _buildHeaderContent(NewsFeedItemGroupState itemGroupDatas) {
    String groupId = itemGroupDatas.groupId;
    return Container(
      padding: const EdgeInsets.only(left: 15, right: 15,),
      child: NewsFeedStickyHeader(title: groupId,),
    );
  }

  List<Widget> _buildGroupContent(List<Map<String, dynamic>> list, int groupIndex,  vm) {
    return list.asMap().entries.map((entry) {
      int childIndex = entry.key;
      Map<String, dynamic> item = entry.value;
      return Container(
        margin: const EdgeInsets.only(left: 15, right: 15, top: 14, bottom: 14),
        color: Colors.white,
        padding: const EdgeInsets.only(left: 15, right: 15, top: 17, bottom: 17),
        height: 280,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            // 卡片中间 （文字和图片）
            Expanded(
              child: NewsFeedCardContent(
                key: UniqueKey(),
                content: item['content'],
                imageUrls: item["imageUrls"],
              ),
            ),
            const SizedBox(height: 26),
            // 卡片底部 (点赞 评论 分享)
            NewsFeedCardFooter(
              key: UniqueKey(),
              isLike: true,
              onLike: () {
                vm.handlerClickActionBtn('like', item);
              },
              onComment: () {
                vm.handlerClickActionBtn('comments', item);
              },
              onShare: () {
                vm.handlerClickActionBtn('share', item);
              },
            ),
          ],
        ),
      );
    }).toList();
  }
}
